#define MOZ_SOURCE_STAMP 9afe68360fa82c16b760b448b2156230a90caf11
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-beta
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-beta/rev/9afe68360fa82c16b760b448b2156230a90caf11
